<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>الرابط URI و المشغل غير متوافقان.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>ثبت hplip أولا ثم أعد تشغيل البرنامج لتثبيت المشغل مجددا.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>الرجاء تعيين مشغل hplip ثم إعادة المحاولة.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>الرابط URI لا يمكن أن يكون فارغ</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation>غير موجود</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>تأكد من تعديلات الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>التأكد من تعديلات الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>لم يتم الحصول على خصائص الطابعة، الخطأ:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>تم تعطيل %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>لا يقبل عمليات طبع</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>تعديلات الطابعة مناسبة</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>تأكد من ربط الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>التأكد من ربط الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>لا يمكن الإتصال بالطابعة، خطأ: 1%</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation>غير متصل، الرابط URI:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 غير موجود</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>لا يمكن الإتصال بالطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>الإتصال مقبول</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>تأكد من الخادم CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>التأكد من الخادم CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>الخادم CUPS غير مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>الخادم CUPS مقبول</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>التأكد من المشغل...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>ملف PPD %1 غير موجود</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>التعريف معطوب</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>لم يتم العثور على عامل تصفية محرك الأقراص %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 غير مثبت، لا يمكن الطبع حاليا</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>المشغل مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>تأكد من المشغل</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="99"/>
        <source>Queuing</source>
        <translation>ترتيب</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="100"/>
        <source>Paused</source>
        <translation>توقف مؤقت</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="101"/>
        <source>Printing</source>
        <translation>طبع</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="102"/>
        <source>Stopped</source>
        <translation>متوقف</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="103"/>
        <source>Canceled</source>
        <translation>ملغى</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="104"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="105"/>
        <source>Completed</source>
        <translation>تمت العملية</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="369"/>
        <source>%1 timed out, reason: %2</source>
        <translation>إنتهى وقت %1، والسبب هو %2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="383"/>
        <source>%1 has been sent to the printer, please take away the paper in time!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="385"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1 %2، السبب: 3%</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>ملف تعريف EveryWhere</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>لم يتم إيجاد حل لملف التعريف: 1%، خطأ: 2%</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>الحل غير مقبول</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>غير مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>لم يتم تثبيت مشغل بالإتصال بالواجهة dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>فشل في تثبيت ٪ 1</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>غير موجود</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>تأكد من طبع الصفحة المسودة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>طبع الصفحة المسودة...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>مدير الطباعة</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>إدارة الطباعة هي أداة إدارة الطابعة ، والتي تدعم إضافة وإزالة الطابعات ، وإدارة مهام الطباعة وما إلى ذلك.</translation>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="260"/>
        <source>Configuring the printer %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="306"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="310"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>